==> zio-aws-sagemaker_3-5.19.8.1-sources.jar: zio/aws/sagemaker/model/UserContext.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UserContext(
    userProfileArn: Optional[String] = Optional.Absent,
    userProfileName: Optional[String] = Optional.Absent,
    domainId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.UserContext = {
    import UserContext.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.UserContext
      .builder()
      .optionallyWith(userProfileArn.map(value => value: java.lang.String))(
        _.userProfileArn
      )
      .optionallyWith(userProfileName.map(value => value: java.lang.String))(
        _.userProfileName
      )
      .optionallyWith(domainId.map(value => value: java.lang.String))(
        _.domainId
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.UserContext.ReadOnly =
    zio.aws.sagemaker.model.UserContext.wrap(buildAwsValue())
}
object UserContext {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.UserContext
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.UserContext =
      zio.aws.sagemaker.model.UserContext(
        userProfileArn.map(value => value),
        userProfileName.map(value => value),
        domainId.map(value => value)
      )
    def userProfileArn: Optional[String]
    def userProfileName: Optional[String]
    def domainId: Optional[String]
    def getUserProfileArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("userProfileArn", userProfileArn)
    def getUserProfileName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("userProfileName", userProfileName)
    def getDomainId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("domainId", domainId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.UserContext
  ) extends zio.aws.sagemaker.model.UserContext.ReadOnly {
    override val userProfileArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.userProfileArn())
      .map(value => value: String)
    override val userProfileName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.userProfileName())
      .map(value => value: String)
    override val domainId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.domainId())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.UserContext
  ): zio.aws.sagemaker.model.UserContext.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_3-5.20.22.3-sources.jar: zio/aws/sagemaker/model/UserContext.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UserContext(
    userProfileArn: Optional[String] = Optional.Absent,
    userProfileName: Optional[String] = Optional.Absent,
    domainId: Optional[String] = Optional.Absent,
    iamIdentity: Optional[zio.aws.sagemaker.model.IamIdentity] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.UserContext = {
    import UserContext.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.UserContext
      .builder()
      .optionallyWith(userProfileArn.map(value => value: java.lang.String))(
        _.userProfileArn
      )
      .optionallyWith(userProfileName.map(value => value: java.lang.String))(
        _.userProfileName
      )
      .optionallyWith(domainId.map(value => value: java.lang.String))(
        _.domainId
      )
      .optionallyWith(iamIdentity.map(value => value.buildAwsValue()))(
        _.iamIdentity
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.UserContext.ReadOnly =
    zio.aws.sagemaker.model.UserContext.wrap(buildAwsValue())
}
object UserContext {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.UserContext
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.UserContext =
      zio.aws.sagemaker.model.UserContext(
        userProfileArn.map(value => value),
        userProfileName.map(value => value),
        domainId.map(value => value),
        iamIdentity.map(value => value.asEditable)
      )
    def userProfileArn: Optional[String]
    def userProfileName: Optional[String]
    def domainId: Optional[String]
    def iamIdentity: Optional[zio.aws.sagemaker.model.IamIdentity.ReadOnly]
    def getUserProfileArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("userProfileArn", userProfileArn)
    def getUserProfileName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("userProfileName", userProfileName)
    def getDomainId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("domainId", domainId)
    def getIamIdentity
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.IamIdentity.ReadOnly] =
      AwsError.unwrapOptionField("iamIdentity", iamIdentity)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.UserContext
  ) extends zio.aws.sagemaker.model.UserContext.ReadOnly {
    override val userProfileArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.userProfileArn())
      .map(value => value: String)
    override val userProfileName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.userProfileName())
      .map(value => value: String)
    override val domainId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.domainId())
      .map(value => value: String)
    override val iamIdentity
        : Optional[zio.aws.sagemaker.model.IamIdentity.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.iamIdentity())
        .map(value => zio.aws.sagemaker.model.IamIdentity.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.UserContext
  ): zio.aws.sagemaker.model.UserContext.ReadOnly = new Wrapper(impl)
}
